#!/usr/bin/env bash

# Script to kick off BVT test run and produce result in results directory
set -oux pipefail

RUN_VER=$(date +"%Y%m%d_%H%M%S")
RUN_REPORT=bvt_${RUN_VER}.html

# Json to be sent to MDM to inform success/failure
MDM_NAMESPACE="APBvts"
METRIC_NAME="BVTResult"
RESULT_JSON="{\"Namespace\":\"${MDM_NAMESPACE}\",\
	    \"Metric\":\"${METRIC_NAME}\",\
	    \"Dims\": {\
		 \"Tenant\":\"$AP_CLUSTER\",\
		 \"MachineName\":\"${AP_MACHINE_NAME}\",\
		 \"Role\":\"${AP_ENVIRONMENT}\",\
		 \"RoleInstance\":\"${AP_MACHINE_FUNCTION}\",\
		 \"SharedServicesVersion\":\"$(dpkg-query --showformat='${Version}' -W aplinux-shared-services)\",\
		 \"OsVersion\":\"$(cat /ap/data/OsVersion)\",\
		 \"ServiceName\":\"apbvts\"}\
	     }"

# Start the tests
/usr/bin/python3 -m pytest --html="./results/${RUN_REPORT}" --self-contained-html
if [ $? -ne 0 ]; then
    RUN_FAIL_REPORT=bvt_fail_${RUN_VER}.html
    mv ./results/"${RUN_REPORT}" ./results/"${RUN_FAIL_REPORT}"
    echo "Test Run - $RUN_VER - FAILED. Error report in file: ${RUN_FAIL_REPORT}"
    RESULT=0
else
    RESULT=1
fi

# Send the metric to MDM. 
echo "$RESULT_JSON:$RESULT|g" | socat -t 0 - UDP:127.0.0.1:9125

exit 0
